summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2015-10-31 08:40:40 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2015-10-31 08:42:07 -0500
commit33bb55d5b1ffcde32e20768b72dcc63fff093e3b (patch)
tree4f653cf708d09d6e603768adcd7e3d24135e5d07 /png.h
parent475bab6170f651b9863e9fc1b8ffd6cd89a45aa0 (diff)
downloadlibpng-33bb55d5b1ffcde32e20768b72dcc63fff093e3b.tar.gz
[libpng12] Imported from libpng-1.2.54rc02.tarv1.2.54rc02
Diffstat (limited to 'png.h')
-rw-r--r--png.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/png.h b/png.h
index 5f8725275..877d45cee 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.2.54rc01, October 28, 2015
*
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -12,7 +12,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.2.54rc01, October 28, 2015: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -299,7 +299,7 @@
* 1.0.63 10 10063 10.so.0.63[.0]
* 1.2.53 13 10253 12.so.0.53[.0]
* 1.2.54beta01 13 10254 12.so.0.54[.0]
- * 1.2.54rc01 13 10254 12.so.0.54[.0]
+ * 1.2.54rc01-02 13 10254 12.so.0.54[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -331,7 +331,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.0.7, July 1, 2000, through 1.2.54rc01, October 28, 2015, are
* Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.0.6
* with the following individuals added to the list of Contributing Authors:
@@ -438,13 +438,13 @@
* Y2K compliance in libpng:
* =========================
*
- * October 28, 2015
+ * October 31, 2015
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.2.54rc01 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*
* Libpng only has three year fields. One is a 2-byte unsigned integer
@@ -500,9 +500,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.2.54rc01"
+#define PNG_LIBPNG_VER_STRING "1.2.54rc02"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.2.54rc01 - October 28, 2015\n"
+ " libpng version 1.2.54rc02 - October 31, 2015\n"
#define PNG_LIBPNG_VER_SONUM 0
#define PNG_LIBPNG_VER_DLLNUM 13
@@ -515,7 +515,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 01
+#define PNG_LIBPNG_VER_BUILD 02
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -1570,7 +1570,7 @@ struct png_struct_def
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef png_structp version_1_2_54rc01;
+typedef png_structp version_1_2_54rc02;
typedef png_struct FAR * FAR * png_structpp;
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.2.54rc01, October 28, 2015
+ * libpng version 1.2.54rc02, October 31, 2015
*
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -12,7 +12,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.2.54rc01, October 28, 2015: Glenn
+ * libpng versions 0.97, January 1998, through 1.2.54rc02, October 31, 2015: Glenn
* See also "Contributing Authors", below.
*
@@ -331,7 +331,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.0.7, July 1, 2000, through 1.2.54rc01, October 28, 2015, are
+ * libpng versions 1.0.7, July 1, 2000, through 1.2.54rc02, October 31, 2015, are
* Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.0.6
@@ -438,13 +438,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.2.54rc01 are Y2K compliant. It is my belief that earlier
+ * upward through 1.2.54rc02 are Y2K compliant. It is my belief that earlier
* versions were also Y2K compliant.
*